# collibra-protect_api_partner
API to retrieve the data access rule set it needs to synchronize. This API is targeted to be used by Collibra Partners.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0-beta
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import collibra_protect_api_partner 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import collibra_protect_api_partner
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import collibra_protect_api_partner
from collibra_protect_api_partner.rest import ApiException
from pprint import pprint
# Configure HTTP basic authorization: basicAuth
configuration = collibra_protect_api_partner.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = collibra_protect_api_partner.SynchronizationsApi(collibra_protect_api_partner.ApiClient(configuration))
data_source = 'data_source_example' # str | Name of the data source

try:
    # Returns the details of the synchronization for the provided data source.
    api_response = api_instance.get_synchronization_by_data_source(data_source)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SynchronizationsApi->get_synchronization_by_data_source: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */rest/protect/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SynchronizationsApi* | [**get_synchronization_by_data_source**](docs/SynchronizationsApi.md#get_synchronization_by_data_source) | **GET** /synchronizations/byDataSource | Returns the details of the synchronization for the provided data source.

## Documentation For Models

 - [Access](docs/Access.md)
 - [BaseMasking](docs/BaseMasking.md)
 - [ConstantMasking](docs/ConstantMasking.md)
 - [CustomMasking](docs/CustomMasking.md)
 - [DataAccessRuleSet](docs/DataAccessRuleSet.md)
 - [Database](docs/Database.md)
 - [DatabaseColumn](docs/DatabaseColumn.md)
 - [DatabaseColumnAccessRule](docs/DatabaseColumnAccessRule.md)
 - [DatabaseColumnTag](docs/DatabaseColumnTag.md)
 - [DatabaseCustomMasking](docs/DatabaseCustomMasking.md)
 - [DatabaseSchema](docs/DatabaseSchema.md)
 - [DatabaseTable](docs/DatabaseTable.md)
 - [DatabaseTableAccessRule](docs/DatabaseTableAccessRule.md)
 - [DatabaseTag](docs/DatabaseTag.md)
 - [DefaultMasking](docs/DefaultMasking.md)
 - [GroupMasking](docs/GroupMasking.md)
 - [HashMasking](docs/HashMasking.md)
 - [Masking](docs/Masking.md)
 - [MaskingMappings](docs/MaskingMappings.md)
 - [MaskingType](docs/MaskingType.md)
 - [NoMasking](docs/NoMasking.md)
 - [Provider](docs/Provider.md)
 - [ProviderDetails](docs/ProviderDetails.md)
 - [RowFilter](docs/RowFilter.md)
 - [RowFilterOperator](docs/RowFilterOperator.md)
 - [ShowLastMasking](docs/ShowLastMasking.md)
 - [StandardErrorResponse](docs/StandardErrorResponse.md)
 - [Synchronization](docs/Synchronization.md)

## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## Author


